package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````NQ4``#0```#HD````````#0`(``*
M`"@`%P`6``8````T````-````#0```!``0``0`$```0````$`````P```'0!
M``!T`0``=`$``!<````7````!`````$````!````````````````````J`\`
M`*@/```$`````!````$`````$````!`````0``!M*@``;2H```4`````$```
M`0````!`````0````$```/1*``#T2@``!``````0```!````\(T``/"=``#P
MG0``-`(``(02```&`````!````(`````C@```)X```">``#0````T`````8`
M```$````4.5T9%!]``!0?0``4'T``/0```#T````!`````0```!1Y71D````
M```````````````````````&````$````%+E=&3PC0``\)T``/"=```0`@``
M$`(```0````!````+VQI8B]L9"UM=7-L+6DS.#8N<V\N,0``$0```$H````(
M````"``````0$``E0`2`*``0!*"&`(2``0``"R`$"3B`$D&*!`@(`````$H`
M``!.````4@```%,```!9````6@```%L`````````70```%X`````````7P``
M`&````!B``````````````!J?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-\0[49-1\
M(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'XD?&`;OCDGQ5PSS29Z_,9H@'<--#
M1=7L,V+;[16,)<Q_J9R;X*<""FL:GE"CX/M)``````````````````````$`
M`````````````!(```#!`0`````````````2````"0``````````````$0``
M`.<!`````````````!$```!C`0`````````````2````$```````````````
M$@```*`!`````````````!(````8```````````````2````'P``````````
M````$@```/0!`````````````!(```"L`0`````````````2````*`,`````
M````````(0```"@``````````````!(````N```````````````2````-0``
M````````````$@```/4"`````````````!(```#F`@`````````````2````
MD`(`````````````$@```#$"`````````````!(````\```````````````2
M````Q0(`````````````$@```$,``````````````!(```!+````````````
M```2````K@(`````````````$@```%,``````````````!(```!<````````
M```````@````WP(`````````````$@```'@``````````````!(```!]````
M```````````2````!0(`````````````$0```,P"`````````````!(```!>
M`@`````````````2````A```````````````$@```(L``````````````"``
M``!0`@`````````````2````>P,`````````````$@```"<#````````````
M`!$```""`@`````````````2````%`,`````````````$@```!`"````````
M`````!(````I`P`````````````1````J0``````````````$@````P#````
M`````````!(```!Q`0`````````````2````L@``````````````(@```,$`
M`````````````!(```#7`@`````````````2````;@(`````````````$@``
M`,8``````````````!(```#,```````````````@````N0(`````````````
M$@```.8``````````````!(```"1`0`````````````2````ZP``````````
M````(`````<!`````````````!(```">`@`````````````2````#0$`````
M````````$@```(`!`````````````!(````;`0`````````````2````+`$`
M````````````$@```"P"`````````````!(````]`@`````````````2````
M,@$`````````````$@```'<"`````````````!(````%`P`````````````2
M````00$`````````````$@```/T"`````````````!(````G`@``````````
M```2````SP$`````````````$@```%4!`````````````!(````Q`P``````
M```````2````)@,`````````````(0```%P!`````````````!(````A`P``
M\!,``,L!```2``H`X0$``&$Z```!````$@`+`+T#``"=(@``O`4``!(`"@!I
M!```52L``%X````2``H`F@,``+P=```%````$@`*`"<$````$````0```!(`
M!P#@`P``62@``/P"```2``H`300``,$=``"E`0``$@`*`!@$```DH```````
M`!``%`"K`P``^2$``*0````2``H`R@,``%(<```[````$@`*`-(#``"!(0``
M30```!(`"@#V`P``X3<``/L````2``H`"P0``&8?```5````$@`*`&0$``!T
ML````````!``%`!@`P``UA4``#<````2``H`+00``'L?``"J````$@`*``$$
M```@H```!````!$`$P!&!```)*`````````0`!,`'00``+L5````````$``*
M`"0$``"/-P``4@```!(`"@!I`P``SB$``"L````2``H`A`,``.(<``#:````
M$@`*`%H$``#<.```)P$``!(`"@`Y!```)2```%P!```2``H``&]P96YD:7(`
M<W1D97)R`')E86QL;V,`86-C97-S`'-N<')I;G1F`&QS965K`&=E='!I9`!S
M=')C;7``=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!C;&]S961I<@!?251-7V1E
M<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R8VAR`%]?9&5R
M96=I<W1E<E]F<F%M95]I;F9O7V)A<V5S`')E861L:6YK`%]?8WAA7V9I;F%L
M:7IE`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D
M`%]?<F5G:7-T97)?9G)A;65?:6YF;U]B87-E<P!R;61I<@!?7W-T871?=&EM
M938T`%]?97)R;F]?;&]C871I;VX`;6MD:7(`7U]L<W1A=%]T:6UE-C0`<'1H
M<F5A9%]G971S<&5C:69I8P!S=')L96X`9V5T=6ED`%!E<FQ?<WES7W1E<FT`
M4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C
M=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H
M:69T`%!E<FQ?<W9?,G!V7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L
M7VYE=UA37V9L86=S`%!,7W1H<E]K97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A
M<`!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E
M<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W
M6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E
M<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&9P
M<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT9@!S
M=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N`%]?
M<W1A8VM?8VAK7V9A:6P`;&EB<&5R;"YS;P!L:6)C+FUU<VPM>#@V+G-O+C$`
M7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E
M;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E
M<FYA;'-?4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N
M86UE`%]?8G-S7W-T87)T`'-H85]I;FET`'!A<E]D:7)N86UE`'!A<E]I;FET
M7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?96YD`'!A<E]C
M;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%``#$GP``"```
M`-"?```(````V)\```@`````H```"`````2@```(````"*````@````,H```
M"````!"@```(````%*````@````@H```"````,B?```&`P``S)\```8$``#4
MGP``!AH``-R?```&'@``X)\```8B``#DGP``!BD``.B?```&+0``[)\```8R
M``#PGP``!C8``/2?```&.```^)\```8Z``#\GP``!CX``-R>```'`0``X)X`
M``<"``#DG@``!P4``.B>```'!@``[)X```<'``#PG@``!P@``/2>```'"0``
M^)X```<*``#\G@``!PL```"?```'#0``!)\```<.```(GP``!P\```R?```'
M$```$)\```<1```4GP``!Q(``!B?```'$P``')\```<4```@GP``!Q4``"2?
M```'%@``*)\```<7```LGP``!Q@``#"?```'&0``-)\```<;```XGP``!QP`
M`#R?```''0``0)\```<?``!$GP``!R```$B?```'(0``3)\```<C``!0GP``
M!R0``%2?```')@``6)\```<G``!<GP``!R@``&"?```'*@``9)\```<K``!H
MGP``!RP``&R?```'+@``<)\```<O``!TGP``!S```'B?```',0``?)\```<S
M``"`GP``!S0``(2?```'-0``B)\```<W``",GP``!SD``)"?```'.P``E)\`
M``<\``"8GP``!ST``)R?```'/P``H)\```=```"DGP``!T$``*B?```'0@``
MK)\```=#``"PGP``!T0``+2?```'10``N)\```=&``"\GP``!T<``,"?```'
M20``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#.A8!P``Z!,J``"#Q`S#````````````````````_[,$````_Z,(````
M`````/^C#````&@`````Z>#_____HQ````!H"````.G0_____Z,4````:!``
M``#IP/____^C&````&@8````Z;#_____HQP```!H(````.F@_____Z,@````
M:"@```#ID/____^C)````&@P````Z8#_____HR@```!H.````.EP_____Z,L
M````:$````#I8/____^C,````&A(````Z5#_____HS0```!H4````.E`____
M_Z,X````:%@```#I,/____^C/````&A@````Z2#_____HT````!H:````.D0
M_____Z-$````:'````#I`/____^C2````&AX````Z?#^____HTP```!H@```
M`.G@_O___Z-0````:(@```#IT/[___^C5````&B0````Z<#^____HU@```!H
MF````.FP_O___Z-<````:*````#IH/[___^C8````&BH````Z9#^____HV0`
M``!HL````.F`_O___Z-H````:+@```#I</[___^C;````&C`````Z6#^____
MHW````!HR````.E0_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^
M____HWP```!HX````.D@_O___Z.`````:.@```#I$/[___^CA````&CP````
MZ0#^____HX@```!H^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(
M`0``Z=#]____HY0```!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG```
M`&@@`0``Z:#]____HZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^C
MJ````&@X`0``Z7#]____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W_
M__^CM````&A0`0``Z4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I
M(/W___^CP````&AH`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!
M``#I\/S___^CS````&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````
M:)`!``#IP/S___^CV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@
M````:*@!``#ID/S___^CY````&BP`0``Z8#\____H^@```!HN`$``.EP_/__
M_Z/L````:,`!``#I8/S___^C\````&C(`0``Z5#\____HQ`!``!FD/^C&`$`
M`&:0_Z,@`0``9I```````````(U,)`2#Y/#_<?R-00A5B>575HG.4^@#`@``
M@</&B@``48/L#%"-00104>A!_O__BX,L`0``@\0,4%#_LR@!``#HR_S__XN#
M_````(/$$(N[#`$``(`X`'4TZ'+]__^)@Z`1``"%P'4*@^P,:@'H#O[__X/L
M#%#H9?[__UK_-^CM_O__@\00QH!]!@```(/L#/\WZ-G^__^`B,X"```"6/\W
MZ,K^__^#Q!"`B,X"```!BP:#P`4]____/W8%Z'_]__^#[`S!X`)0Z//]__^+
M?@2#Q!"Y`0```(F#E!$``,>#F!$```0```"+%XD0C9/CH___B5`$BY-0`0``
MB5`(C9/FH___B5`,BQ8YRGX*BS2/B72(#$'K\H/L#,=$D`P`````@\(#:@!0
MC8.]??__4E#_LZ`1``#H1?S__X/$((G&A<!U$X/L#/^SH!$``.A._?__@\00
MB<:#[`S_LZ`1``#HN_S__XV#[Z'__^C>`@``@\00A<!U,(.[G!$```!U$8V#
MI*'__^C#`@``B8.<$0``BX.<$0``A<!T#(/L#%#HP14``(/$$(/L#/^SH!$`
M`.C;_?__Z*;Z__^#Q!"-9?")\%E;7E]=C6'\PS'MB>"#Y/!04.@`````@00D
M-X@``%#H`````%/H,0```('#](@``(/L$(M$)!AJ`(U0!/^S``$``/^S"`$`
M`%+_,/^S]````.@8_/__@\0H6\.+'"3#9I!FD&:09I!FD&:09I"0Z(4!``"!
MPJN(``"-BE0!``"-@E0!```YR'0=BX($`0``A<!T$U6)Y8/L%%'_T(/$$,G#
MC70F`)##C;0F`````.A%`0``@<)KB```58GE4XV*5`$``(V"5`$``(/L!"G(
MB</!Z!_!^P(!V-'X=!2+DAP!``"%TG0*@^P(4%'_TH/$$(M=_,G#C;0F````
M`&:058GE5^CU````@<<7B```5E.#[`R`OW`!````#X5_````BY<8`0``A=)T
M$X/L#/^W,`$``(G[Z.W\__^#Q!"-MRC___^-GRS___^+AW0!```I\\'[`H/K
M`3G8<QJ-="8`@\`!B8=T`0``_Q2&BX=T`0``.=ARZNCU_O__BX<0`0``A<!T
M%(/L#(V'Q-___XG[4.B*_/__@\00QH=P`0```8UE]%M>7UW#C;0F`````)!5
MZ`````!:@<)JAP``B>53Z)C^__^!PUN'``"#[`2+@R`!``"%P'09C8-X`0``
M4FH`4(V#Q-___U#H0OS__X/$$(M=_,GIMO[__XL4),.+/"3#55=6,?93Z%#^
M__^!PQ.'``"#[!R)5"0$A<!T9HG!BX,4`0``,?:)S8L0A=)T5(I%`(3`=`<\
M/70#1>OR*<V)UXLWA?9T/(E4)`Q055&)3"045NA7^?__@\00BTPD"(M4)`R%
MP'47@#PN/741BT0D!"G7C70N`<'_`HDXZP6#QP3KOH/$'(GP6UY?7<.#[!QE
MBPT4````B4PD##')C50D".A;____BTPD#&4K#10```!T!>B>(0``@\0<P^@X
M____@<)>A@``5E.)PX/L%&6A%````(E$)`PQP(NR%`$``(U4)`B)V.@6____
MA<!T%XL&BU0D"(T$D(M0!(D0A=)TWX/`!.ORBT0D#&4K!10```!T!>@^(0``
M@\046U[#55>)QU93Z#/]__^!P_:%``"![+P```!EH10```")A"2L````,<"%
M_P^$!@$``(`_``^$_0```(/L#%?H(??__XE$)!2#Q!"%P`^$Y0```(V#6Z'_
M_XE$)`B-@UJA__^)1"0,@^P,_W0D$.BR]___@\00A<`/A*,```"-<!-24O]T
M)!!6Z(CW__^#Q!"%P'334%#_="045NAU]___@\00A<!TP(/L#%?H)?K__XDT
M)(G%Z!OZ__^-1`4"B00DZ*_W__]6B<6-@UVA__]74%7HSOG__X/$&(U$)"10
M5>A`^?__@\000'09BT0D+"4`\```/0!```!U"8GHZ`+____K#(/L#%7H6/?_
M_X/$$(/L#%7H//G__X/$$.E&____@^P,_W0D$.B(]___B3PDZ.#X__^#Q!"+
MA"2L````92L%%````'0%Z.\?``"!Q+P```!;7E]=PU:)QE/HX?O__X'#I(0`
M`('LK````&6A%````(F$)*0````QP(U$)!105NC>^/__@\00A<!U,8M4)!R!
MX@#P``"!^@!```!T"('Z`*```'494%!J`E;H`_;__X/$$(7`#Y3`#[;`ZP(Q
MP(N,))P```!E*PT4````=`7H9A\``('$I````%M>PU57B<=6B=93Z%;[__^!
MPQF$``"#["QEH10```")1"0<,<"`.CUU`4:#[`Q6Z,7X__^#Q!")1"0(C50D
M&(GXZ,7\__^)Q87`="F#[`Q0Z*3X__^#Q!`Y1"0(#X>_````,<"*%`:(5`4`
M0(32=?3I'`$``(N#%`$``,=$)`0`````BPB+1"0$@SR!`'0&_T0D!.OP@[N0
M$0```(TLA0@```!T'5)255'H"_7__XN3%`$``(/$$(D"A<!U3.G/````B4PD
M#(/L#%7'@Y`1```!````Z,#U__^#Q!")PH7`#X2K````4(U%^%"+3"0445*)
M5"0<Z*_U__^+5"0<BX,4`0``@\00B1"+@Q0!``"+`,=$*/P`````BT0D!(E$
M)!B)^(H0A-)T"(#Z/70#0.ORBZL4`0``BTPD&(/L#"GXBU4`C12*B50D$(M,
M)!2-1`$"4.A!]?__BU0D%(/$$(D"A<!T+(M%`(M4)!B+!)"*%T>)P4"(4/^$
MTG0%@/H]=>[&`3TQTHH,%H@,$$*$R77UBT0D'&4K!10```!T!>B]'0``@\0L
M6UY?7<-3Z+7Y__^!PWB"``"#[!2+@PP!``#_,.CR]O__C9-TWO__4HV38Z'_
M__^S)`$``%)0Z+CV__^#Q"A;PU93Z'GY__^!PSR"``"#[!"+LPP!``#_-NBV
M]O__B00DZ*#___]8_S;HIO;__UE>:@")PHV#XJ/__U!0C8.)B?__4(V#?Z'_
M_U!2Z,3S__^#Q"1;7L-55U93Z"+Y__^!P^6!``"![!P@``!EH10```")A"0,
M(```,<#HQ?/__X/L#(V3E*'__U)0C8.8H?__4&@!$```C6PD)E7H9//__X/$
M((U0`8'Z`1```'8"#PM`=00QP.M94&@`$```C;0D$Q```%95Z.GT__^#Q!")
MQ87`>-^#[`R-0`%0Z-3S__^#Q!"%P'3,.?!S!XT4*#G6<KPY\'8'C10N.=!R
ML8']`1```'^I_(G'B>GSI,8$*`"+C"0,(```92L-%````'0%Z%8<``"!Q!P@
M``!;7E]=P^DA____55=64^A#^/__@<,&@0``@>R\$```9:$4````B80DK!``
M`#'`B[0DT!```(N\)-00``"-@Z2A___H0/K__XD$)%55:B]6Z-7S__^#Q!"%
MP'02B?*-@ZVA___HB_S__^D@`0``@^P,C:NZH?__5NAM]?__6EF)1"0,55?H
M$/7__X/$$(G'C8-;H?__B40D"(V#O*'__XE$)`R%_W2U@#\`=02+?"0(@SPD
M`'074%!7_W0D#.AH\O__@\00A<`/A*T```"#[`Q7Z!3U__^#Q!"`?`?_+W4'
M2,8$!P#K\HM,)`2-1`@!/?\/```/CV+___]04(V#C:+__U;_="085U!H`!``
M`(V\),@```!7Z+_Q__^#Q"!`/0`0``!V`@\+45&-1"0D4%?H!?3__X/$$(7`
M=3Z+1"0L)0#P```]`(```'4N4E)J`5?H=/'__X/$$(7`=1V)^HV#K:'__^B*
M^___@^P,5^AG\O__@\00B<;K%%!056H`Z!;T__^#Q!")Q^D5____BX0DK!``
M`&4K!10```!T!>BN&@``@<2\$```B?!;7E]=PXM4)`2)T(H*A,ET"$*`^2]U
M].OPPU934XMT)!#HAO;__X'#27\``(7V=#B`/@!T,X/L#%;H`?3__X/$$(U$
M!O\YQG,6@#@O=0U(Z_2`."^-4/]T,XG0.<9R\CG&=2F`/B]U"X/L#(V#6Z'_
M_^L)@^P,C8.\H?__4.BM\?__@\00ZSF`."]U!4@YQG+V*?"-4`*!^@`0``!W
M($`]`!```'8"#PM14%:-LY`!``!6Z#CR__^#Q!")\.L",<!:6U[#5[DB````
M5E/HV_7__X'#GGX``(/L,&6A%````(E$)"PQP(U\)`J-LU#>___\\Z2-@[ZA
M___H#OC__XV#QZ'__^@#^/__C8//H?__Z/CW__^-@]BA___H[??__XV#WZ'_
M_^CB]___C8/OH?__Z-?W__^-@Z2A___HS/?__XV#^Z'__^C!]___C8,%HO__
MZ+;W__^-@P^B___HJ_?__XV#K:'__^B@]___C8,9HO__Z&;W__^%P'0-B<*-
M@P6B___HP?G__XV#*J+__^A*]___B<*%P'0+C8,UH?__Z*7Y__^-@SRB___H
M+O?__XG"C8.DH?__A=)U-HV#3*+__^@7]___B<*%P'4?4(V#7:+__VH*4(U$
M)"=0Z!_P__^#Q!"%P'4/C50D)8V#^Z'__^A3^?__C8/?H?__C9-HHO__Z$+Y
M__^+1"0L92L%%````'0%Z(T8``"#Q#!;7E_#4^B&]/__@<-)?0``@^P(@[M,
M`0``_W4JC8/[H?__Z)KV__^)PC'`A=)T$8H2@/HP#Y7!,<"$T@^5P"'(B8-,
M`0``BX-,`0``@\0(6\-3Z#GT__^!P_Q\``"#[`CHWO'__X/L#%#H%?#__X/$
M$(7`=`*+`(/$"%O#55=64^@+]/__@</.?```@^P<BWPD,(V#:J+__^@D]O__
MA<!T!X`X`(G&=0V)^HV#:J+__X/$'.M:4%!75NAU[___@\00A<!U4X/L#%?H
M5?'__XDT)(G%Z$OQ__^-1`4"B00DZ-_N__^)-"2)PHV#NJ'__U"-@XVB__]7
M4%*)5"0LZ/'P__^+5"0LC8-JHO__@\0\6UY?7>D5^/__@\0<6UY?7<-5N08`
M``!75E/H8O/__X'#)7P``('L+($``(N$)$"!``"-O"3$````B40D"(VS-`$`
M`&6A%````(F$)!R!```QP(V#,*'__\>$)+0`````````B80DK````(V#6Z'_
M_XF$)+````#\\Z6-@TRA___'A"3``````````(F$)+@```"-@U&A__^)A"2\
M````C8.DH?__Z`CU__^%P'0A@#@`B<9T&H/L#%#HK_[__XDT).@^[O__B40D
M$.G8!```Z&[^__^-O"2X````B<:%P'4SBP>%P'0GZ,;T__^%P'4%@\<$Z^R`
M.`!T]H/L#%#H`>[__X/$$(G&A<!TY.L&C;-ZHO__@^P,5NCW[___C40``8D$
M).B+[?__@\00C9.!HO__B<>)Q0^V!H3`=!E11E!2B50D#%6#Q0+HEN___X/$
M$(L4).O@C;0DQ````(LNA>UT*8GHZ$CT__^)Q87`="6`.`!T(.@=]O__A<!T
M%X/L#%7H?>W__X/$$(G%C;0DK````.LR@\8$Z\.+%H72="N`.@!T)HG0B10D
MZ.CU__^+%"2%P'0.@^P,4NA%[?__@\00B<6#Q@2%[73/@^P,5>A`[___B3PD
MB<;H-N___XVT!@0$``")-"3HQ^S__XE$)!18C8.&HO__6E=0C8.\H?__B40D
M'%"-@XNB__]54/]T)"#HS>[__X/$&&C``0``_W0D$.A<[O__@\000'4SZ$'N
M__^+`(/X$70G@^P,4/]T)!2+1"0<_S"-@Y2B__]0BX/X````_S#HF.W__X/$
M(.LZ556-1"0D4/]T)!#H,^[__X/$$(G%A<!T+?]T)`2+1"0,_S"-@\^B__]0
MBX/X````_S#H7.W__X/$$,<$)`````#I`P,``(M$)"PE`/```#T`0```=<.+
M?"0TZ'3N__\YQW6VBT0D+"7_`0``/<`!``!UIH/L#%;HU^O__XE$)!"-@W6B
M___HQO+__X/$$(7`=0B+1"0(BS#K((/L#%#H`.S__UY?4(M$)!3_,.@C^/__
M@\00B<:%P'38@^P,5NCP[?__@\00B<>#^`-V7HV#(J/__U%14(U$/OQ0Z!/K
M__^#Q!"%P'5$@_\$=`>`?#[[+W4XBT0D"(MX!(7_="V#[`Q7Z*SM__^#Q!"#
M^`-V'(U$!_Q24HV3)Z/__U)0Z-'J__^#Q!"%P'4"B?[H9/O__XG'A<`/A64!
M``!04&H`5NAOZ___@\00B<:%P`^$3@$``&H":O]J[E#H=NK__X/$#&H&C:PD
M)`$``%56Z&/L__^#Q!"`O"0<`0```'5=@+PD'0$``$-U4X"\)!X!``!!=4F`
MO"0?`0``0W4_@+PD(`$``$AU-8"\)"$!``!%=2MJ`FK_:L96Z!CJ__^#Q`QJ
M*556Z`SL__^-@^*C__]>7U!5_W0D'.FI````:@!J`&H`5NCMZ?__Z+<0``")
MQ8/$$%%H`(```(V4)"0!``!2B50D%%;HR^O__X/$$(M4)`B%P'X+45!25>C8
M$```Z\^#[`Q6Z(SK__]86E6-M"3K````5NBX$0``@\00C9.!HO__50^V!#Y0
MC00_1U*-K"3_````B50D%`'H4.@E[/__@\00@_\4BU0D"'76C8/BH___QH0D
M&P$```!75U"-@[RA__]54(V#+*/___]T)!A0_W0D'.CLZ___@\0@Z8(```"-
MDVBB__^-@_NA___H#?/__XV[2:/__^@HZ?__5E:-L^*C__]64(V#.Z/___]T
M)!S_="084/]T)!SHINO__X/$(%)2:,`!``#_="0,Z#/K__^#Q!!`=2OH&.O_
M_X,X$74AZ-[H__]%45954/]T)!S_="085_]T)!SH9^O__X/$(.N_@^P,_W0D
M$.@&Z___BU0D$(V#I*'__^B!\O__6/]T)`SHQOG__X/$$(N$)!R!``!E*P44
M````=`7HO!$``(L$)('$+($``%M>7UW#55=64^BK[?__@<-N=@``@^PHB[,,
M`0``_S;HZ.K__UW_-HG'Z-[J__^*5V2(4&6-@]^A___HJ^___X/$$(7`=`N`
M.#%U!H!X`0!T!>A[]___@^P,_S;HK.K__XV36J/__VH+:@%24.@+Z?__@\0@
MA<!U+8/L#/\VZ(KJ__^-DU^C__]J`VH!4E#HZ>C__X/$((G'A<`/A<P```#I
M"P$``(M`#+\!````BV@8C4?_B40D"(L&.;N8$0``?AV#[`Q0Z$+J__]J`/]T
M)!Q54.CEY___@\0@A<!U%(N#F!$``$@[1"0(=8V_`0```.M4BQ"+0@@E``0@
M`#T`!```=06+0@SK((E4)`R#[`S_-NCVZ?__:@)J`(M4)"124.@7ZO__@\0@
M45%0BX.4$0``_S2XZ%/G__^#Q!"%P'6>1^EJ____BP8YNY@1```/CB3___^#
M[`Q'4.BNZ?__65I54.B%YO__@\00Z]J+0`R#[`R+*/\VZ)'I__^#Q`R-DV&C
M__]255#H$.C__XM'#(/$$(LX]D<*0'06@^P,_S;H:.G__UU:5U#H'^?__X/$
M$(/L#/\VZ%+I__^-DW^C__]J`VH!4E#HL>?__X/$((G%A<!T9XV#K:'__^@+
M[O__B<>%P'0%BT4,ZS?HG_+__X7`B<>+10QT(8/L#(LH_S;H".G__X/$#%=5
M4.B-Y___B3PDZ+7H___K'XN3E!$``(LZBRB#[`S_-NC?Z/__@\0,5U50Z&3G
M__^#Q!"#[`S_-NC'Z/__@\0,C9-FH___:@%24.C%Y?__6O\VB<?HJ^C__X/$
M#(V3>Z/__U)74.@JY___6?\VZ)+H___&0&4`C8.DH?__Z&'M__^#Q!")@YP1
M``"%P'4F@^P,_[.4$0``Z*7W__^#Q!")@YP1``"%P'4+@^P,C8.!H___ZS=0
M4&C``0``_[.<$0``Z.[G__^#Q!"-4`&#^@%V((/X$70;4(N#E!$``/^SG!$`
M`/\PC8.BH___4.ACY?__@\0<6UY?7<-75E.+="00Z*SJ__^!PV]S``"#[`Q6
MZ`OT__^)!"3H[O/__X/$$(G'Z/_U__^%P'0IA?9T)8`^`'0@4%"-@X:B__]0
M5^@2YO__@\00.<=U"EN)\%Y?Z2#M__];7E_#53'25U93@>Q\`0``B40D"&6A
M%````(F$)&P!```QP(M$)`B+3)`<C40D+`_)B0R00H/Z$'7IC8PD+`$``(M0
M-#-0((/`!#-0!#-0_-'"B5`\.<AUZ(M$)`B+`(E$)!"+1"0(BU0D$(M`!,'*
M`HE$)!B+1"0(BTPD&(M`",')`HE$)`R+1"0(BWPD#(ML)`R+0`PQSR-\)!`S
M?"0,B40D%(M$)`B+0!")1"0<BT0D+(M<)!R-M`.9>8):BT0D$(M<)!3!P`4!
M\(MT)`PS="04(W0D&#-T)!0!QHM$)#"-A`.9>8):B<L!QXGP,=/!P`4A\\'.
M`@''BT0D-#'+C80%F7F"6HML)#@!PXGXP<`%C8PIF7F"6HML)#P!PXG0,?`A
M^,'/`C'0C90JF7F"6HML)$`!R(G9P<$%`<B)\3'Y(=DQ\8VT+IEY@EJ+;"1$
M`=&)PL'"!<'+`@'1B?HQVB'"P<@",?J-O"^9>8):BVPD2`'RB<[!Q@4!\HG&
MB=@Q\"'(,=B-G"N9>8):BVPD3`'XB=?!QP4!^(G/B?'!SP(Q^2'1,?&-M"Z9
M>8):BVPD4`'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J-O"^9>8):BVPD5`'R
MB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD6`'XB=?!QP4!^(G/B?'!SP(Q
M^2'1,?&-M"Z9>8):BVPD7`'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J-O"^9
M>8):BVPD8`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD9`'XB=?!QP4!
M^(G/B?'!SP(Q^2'1,?&-M"Z9>8):`=F)P\'#!0'9B=.)^L'+`C':(<+!R`(Q
M^HG%B=@!\HG.,>C!Q@4AR,')`@'RBW0D:#'8C;0WF7F"6HGO`?")UC'/P<8%
M(=?!R@(!\(MT)&PQ[XV<,YEY@EJ)S@'?B<,QUL'#!2'&P<@"`=^+7"1P,<Z-
MG!V9>8):BVPD=`'>B?O!PP6-C"F9>8):BVPD>`'>B=,QPR'[,=/!SP*-E"J9
M>8):`<N)\<'!!0'+B<$Q^2'QP<X",<$!T8G:P<(%`=&+5"1\C800H>O9;HGZ
M,?(QVL'+`@'"B<C!P`4!PHN$)(````"-O`>AZ]ENB?`QV#'(`?B)U\''!0'X
MB<^+C"2$````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DB````,'.
M`HV<$Z'KV6Z)^C'R,<(!VHG+P<@"P<,%`=J)PXN$)(P```"-O`>AZ]ENB?`Q
MV#'(`?B)U\''!0'XB<^+C"20````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!
M\8G6BY0DE````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$))@`
M``"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2<````P<\"C;0.H>O9;HG9
M,?DQT0'QB<;!Q@4!\8G6BY0DH````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+
MP<,%`=J)PXN$)*0```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2H````
MP<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DK````,'.`HV<$Z'KV6Z)
M^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+````"-O`>AZ]ENB?`QV#'(`?B)U\''
M!0'XB<^+C"2T````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DN```
M`,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+P```"-O`>AZ]EN
MB?`QV#'(`?B)U\''!0'XB<^+C"3`````P<\"C;0.H>O9;HG9,?DQT0'QB<;!
MQ@4!\8G6BY0DQ````,'.`HV<$Z'KV6Z)^C'R,<+!R`*)Q0':BX0DR````(G+
MP<,%`=J-G`>AZ]ENB?`QZ#'(`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H"
M"?N+O"3,````C;0^W+P;CXG/`?.)Q@G7P<8%`?.)_HG/(<8AU\'(`@GWB[0D
MT````(VT-=R\&X\!]XG>P<8%`?>)U@G&(=[!RP*)]8G6(<8)[HNL)-0```"-
MC"G<O!N/B=V)PP'.">N)^2'[P<$%`<Z)V8G#(>L)RXN,)-@```"-E`K<O!N/
MB>D!T\'/`HGR"?G!P@4A\0'3P<X"B<J)Z2'Y"=&+E"3<````C800W+P;CXGZ
M`<&)V`GRP<`%`<&)T(GZ(=@A\L'+`@G"BX0DX````(V$!=R\&X\!PHG(P<`%
M`<*)\`G8(<B)Q8GP(=@)Z(NL).0```"-O"_<O!N/`?B)U\''!0'XB<^)V<'/
M`@GY(=&)S8G9(?D)Z8NL).@```"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR
M(<+!R`*)U8GZ(?()ZHNL).P```"-G"O<O!N/`=J)R\'#!0':B<.)\`G8(<B)
MQ8GP(=@)Z(NL)/````"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)S8G9
M(?D)Z8NL)/0```"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<*)U8GZ(?()
MZHNL)/@```"-G"O<O!N/`=J)R\'(`L'#!0':B<.)\`G8(<B)Q8GP(=@)Z(NL
M)/P```"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)S8G9(?D)Z8NL)``!
M``"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<+!R`*)U8GZ(?()ZHNL)`0!
M``"-G"O<O!N/B<6)\`':">B)RR'(P<,%`=J)PXGP(>@)V(N<)`@!``"-G!_<
MO!N/`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H""?N+O"0,`0``C;0^W+P;
MCP'SB<;!Q@4!\XG."=:)]XG.(<<AUL'(`@G^B[PD$`$``(V\/=R\&X\!_HG?
MP<<%`?Z)UPG'(=_!RP*)_8G7(<<)[XNL)!0!``"-C"G<O!N/`?F)]\''!0'Y
MB<<)WR'WB?V)QR'?">^+K"08`0``C90JW+P;CP'7B<K!S@+!P@4!UXN4)!P!
M``"-E!#6P6+*B=@Q\#'(P<D"`=")^L'"!0'0BY0D(`$``(V<$];!8LJ)\C'*
M,?K!SP(!VHG#P<,%`=J+G"0D`0``C;0>UL%BRHG+,?LQP\'(`@'SB=;!Q@4!
M\XG&BX0D*`$``(V,`=;!8LJ)^#'P,=`!R(G9P<$%`<B)T8N4)"P!``#!R0*-
ME!?6P6+*B?<QSS'?`=>)PL'"!0'7BY0D,`$``,'+`HVT%M;!8LJ)RC':,<+!
MR`(!\HG^P<8%`?*)QHN$)#0!``"-A`'6P6+*B=DQ\3'YP<\"`<&)T,'`!0'!
MBX0D.`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)TXN4)#P!``"+;"00P<L"
MC906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)$`!``"-O!?6P6+*B=HQRC'"
MP<@"`?J)]\''!0'ZB<>+A"1$`0``C80#UL%BRHG+,?LQ\\'.`@'#B=#!P`4!
MPXN$)$@!``"-C`'6P6+*B?@Q\#'0`<B)V<'!!0'(B=&+E"1,`0``P<D"C907
MUL%BRHGW,<\QW\'+`@'7B<+!P@4!UXN4)%`!``"-M!;6P6+*B<HQVC'"P<@"
M`?*)_L'&!0'RB<:+A"14`0``C80!UL%BRHG9,?$Q^<'/`@'!B=#!P`4!P8N$
M)%@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"1<`0``P<L"C906UL%B
MRHG^,=XQSL')`@'6B<+!P@4!UHN4)&`!``"-O!?6P6+*B=HQRC'"P<@"`?J)
M]\''!0'ZB[PD9`$``(V\.];!8LJ)RS'#,?/!S@(!^XG7P<<%`?N+O"1H`0``
MC;P]UL%BR@'/B<$Q\0-T)!0QT<'*`@-4)`P!^8G?`UPD&,''!0'YBWPD"`-$
M)!R)#XE?!(E7"(EW#(E'$(N$)&P!``!E*P44````=`7H@P(``('$?`$``%M>
M7UW#4^AXWO__@<,[9P``@^P4:F#HF]G__\<``2-%9\=`!(FKS>_'0`C^W+J8
MQT`,=E0R$,=`$/#ATL/'0!0`````QT`8`````,=`7`````"#Q!A;PU575E.#
M[!R+;"0XBUPD,(MT)#2-!.T``````T,4<P/_0QB)0Q2+>UR)Z,'H'0%#&(U#
M'(E$)`B%_W14N4````")Z"GY.<U^`HG(C5,<`?HY\G,*C0P".<YS`_P/"XT\
M!HE\)`PY\G8$.?IR[OR)UXG!*<7SI(M+7`'!B4M<@_E`=7&)V.A)\___BW0D
M#.L!_(/]/WXP.W0D"'8'C4-<.<9RN8U&0(E$)`PY="0(=@8Y1"0(<J:+?"0(
MN1````"#[4#SI>N].W0D"'8*BT0D"`'H.<9RACMT)`AS#8T$+CE$)`@/@G/_
M__^+?"0(B>GSI(EK7(/$'%M>7UW#Z"(!```%[V4``%575E.#[!R+7"0TBW0D
M,(E$)`2+0Q2+4QB)Q<'H`P_*B50D"(/@/XU3'`_-C7@!B50D#,9$`QR``?J#
M_SA^*;E`````*?G\,<")U_.JB=B->QR)3"0,Z'+R__^+1"0,N0X```#SJ^L.
MN3@````I^?PQP(G7\ZJ+1"0(B6M8B4-4B=CH1O+__XL#@^P,P>@8B`:+`\'H
M$(A&`8L#B&8"BP.(1@,/MD,'B$8$#[=#!HA&!8M#!(AF!HM#!(A&!P^V0PN(
M1@@/MT,*B$8)BT,(B&8*BT,(B$8+#[9##XA&#`^W0PZ(1@V+0PR(9@Z+0PR(
M1@\/MD,3B$80#[=#$HA&$8M#$(AF$HM#$(A&$U.+7"04Z"79__^#Q"Q;7E]=
MPXL$),-3Z`#<__^!P\-D``"#[`CHE=G__X/$"%O#Z(7=__^!PJMD``"+@B#_
M__^#^/]T*E6)Y5.-FB#___^#[`2-="8`D/_0BT/\@^L$@_C_=?.+7?S)PXVV
M`````,.#[`SH1]S__X/$#,,`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"]T;7``4$%27U1-4$1)4@!414U01$E2`%1-4`!54T52`%5315).04U%
M`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!2
M3T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)5
M1P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`'!A<BT`)7,E<R5S)7,`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-3``56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L
M;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF
M:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q
M,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I
M('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@
M)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*
M?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*
M=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O
M<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\
M(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B
M=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L
M("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D
M9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@[
M"GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC
M<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I
M;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN
M;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I
M;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL
M;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G
M/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE
M("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+
M7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A
M7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*
M)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>
M0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0[
M"GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF
M("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@
M;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,
M12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*
M8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M
M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B
M1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT
M*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!
M1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/
M.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\
M?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD
M9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@`````'!E<FQX<VDN8P````$;`SOP
M````'0```-"2__\,`0``@);__S`!``"@EO__0`P``&*:__]$`0``[IK__Y`!
M```=F___J`$``'^;___4`0``TYS__YP"``!:G?__Z`(```*?__]H`P``/9__
M_Y@#``"2G___Y`,``&R@__]@!```<:#__W0$```6HO__;`4``"NB__^`!0``
MU:+__]`%```QI/__%`8``'ZD__\T!@``J:3__V`&``!-I?__X`8```FK__]H
M"@``!:[__^P+``!CKO__B`P``#^Z___(#```D;K__^P,``",N___*`T``+.\
M__]L#0``M[S__X`-```4``````````%Z4@`!?`@!&PP$!(@!```@````'```
M`+R1__^P`P````X(1@X,2@\+=`1X`#\:.RHR)"(0````0````$B5__\8````
M`````$@```!4````%IG__XP`````00X(A0)!#@R'`T$.$(8$0PX4@P5.#C!W
M#C1!#CA!#CQ%#D!(#C!K#A1#PPX00<8.#$''#@A!Q0X$```4````H````%:9
M__\O`````$,.(&L.!``H````N````&V9__]B`````$P."(8"00X,@P-%#B`"
M30X,0<,."$'&#@0``,0```#D````HYG__U0!````00X(A0)!#@R'`T,.$(8$
M00X4@P51#M`!8P[<`4$.X`%,#M`!7P[<`40.X`%(#M`!3`[4`4$.V`%$#MP!
M00[@`4@.T`%%#M0!00[8`40.W`%!#N`!2`[0`4<.W`%!#N`!7`[D`4D.Z`%!
M#NP!00[P`4@.V`%%#MP!00[@`4@.T`%?#MP!00[@`4@.T`%##MP!00[@`4@.
MT`%(#MP!1`[@`5`.T`%;#A1!PPX00<8.#$''#@A!Q0X$2````*P!```OFO__
MAP````!!#@B&`D,.#(,#40ZX`50.O`%!#L`!2`ZP`5\.M`%!#K@!0@Z\`4$.
MP`%(#K`!9PX,0<,."$'&#@0``'P```#X`0``:IK__Z@!````00X(A0)!#@R'
M`T,.$(8$0PX4@P5.#D!5#DQ!#E!(#D!8#DQ!#E!(#D`"3@Y$00Y(00Y,00Y0
M3@Y`4@Y,00Y04@Y`2PY$1`Y(10Y,00Y05@Y`=PY,50Y03`Y``D<.%$'##A!!
MQ@X,0<<."$'%#@0`+````'@"``"2F___.P````!!#@B#`DX.'$@.($P.)$P.
M*$$.+$$.,$@."$'##@0`2````*@"``"=F___50````!!#@B&`D$.#(,#3@X<
M2`X@3@X<0@X@1@X<00X80@X<20X@00XD1PXH1PXL00XP2`X,0<,."$'&#@0`
M`'@```#T`@``IIO__]H`````00X(A0)!#@R'`T$.$(8$00X4@P51#K!`5PZ\
M0$<.P$!!#L1`1P[(0$4.S$!%#M!`2`ZP0%4.M$!%#KA`2`Z\0$$.P$!(#K!`
M20Z\0$0.P$!(#K!``D@.%$'##A!!Q@X,0<<."$'%#@0````0````<`,```2<
M__\%`````````/0```"$`P``]9O__Z4!````00X(A0)!#@R'`T$.$(8$00X4
M@P51#M`A;`[4(4$.V"%"#MPA00[@(4@.T"%9#MPA1P[@(48.W"%!#M@A10[<
M(4$.X"%(#M`A:@[4(4$.V"%!#MPA1`[@(4@.T"%+#MPA00[@(4@.T"%B#M0A
M00[8(4<.W"%$#N`A00[D(4$.Z"%%#NPA2`[P(4@.T"%+#M0A00[8(44.W"%!
M#N`A2`[0(54.U"%!#M@A0@[<(4$.X"%(#M`A5`[<(4$.X"%(#M`A10[4(4$.
MV"%!#MPA0@[@(4@.T"%B#A1#PPX00<8.#$''#@A!Q0X$$````'P$``"BG/__
M%0````````!,````D`0``*.<__^J`````$$."(8"00X,@P-!#A!;#AQ!#B!(
M#A!J"@X<2`M##AQ'#B!(#A!D#A1!#AA!#AQ'#B!(#A!'#@Q!PPX(0<8.!$``
M``#@!```_9S__UP!````00X(AP)&#@R&`T$.$(,$3@Y``O,.1$@.2$$.3$4.
M4$@.0'D.$$'##@Q!Q@X(0<<.!```'````"0%```5GO__30````!!#@B#`DX.
M$'P."$'##@0H````1`4``$*>__\K`````$$."(,"3@X02`X<00X@2`X020X(
M0<,.!````'P```!P!0``09[__Z0`````00X(A0)!#@R'`T$.$(8$00X4@P5.
M#C!E"@X40@M!#C1!#CA!#CQ!#D!(#C!'#CQ!#D!G#D1'#DA!#DQ!#E!6#A1!
MPPX00<8.#$''#@A!Q0X$10XP@P6%`H8$AP-##A1!PPX00<8.#$''#@A!Q0X$
MA`,``/`%``!EGO__O`4```!!#@B%`D8.#(<#00X0A@1!#A2#!5$.P(("`HT*
M#LR"`D$.T(("5@MN#LR"`D$.T(("2`[`@@)1#LR"`D$.T(("5`[`@@)2#L2"
M`D(.R(("00[,@@)%#M""`DL.P(("<`[,@@)!#M""`D@.P((";P[,@@)!#M""
M`D@.P(("3`[,@@)!#M""`F,.S(("1P[(@@)!#LR"`D$.T(("2P[4@@)'#MB"
M`D$.W(("1`[@@@)(#LB"`D4.S(("1`[0@@)(#L""`E(.S(("00[0@@)$#M2"
M`D8.V(("1P[<@@)(#N""`D@.P(("0P[$@@)!#LB"`D4.S(("1`[0@@)(#L""
M`DH.Q(("1@[(@@)'#LR"`D@.T(("2`[`@@)\#LR"`D$.T(("5P[`@@)/#LR"
M`D$.T(("1@[,@@)!#LB"`D$.S(("1@[0@@)(#L""`DD.S(("00[0@@)(#L""
M`DX.Q(("00[(@@)!#LR"`D4.T(("2`[`@@)>#LR"`D$.T(("2`[`@@)*#L2"
M`D$.R(("1P[,@@)!#M""`D@.P(("5@H.Q(("00[(@@)"#LR"`D$.T(("2`[`
M@@),#L2"`D(.R(("0@[,@@)!#M""`D@.Q(("0@[(@@)(#LR"`D$.T(("2`[`
M@@)^#L2"`D(.R(("0@[,@@)!#M""`D@.Q(("0@[(@@)!#LR"`D$.T(("3`[,
M@@)!#LB"`D$.S(("00[0@@)$#M2"`D4+0@[$@@)"#LB"`D(.S(("00[0@@)/
M#L""`D$.Q(("10[(@@)(#LR"`D4.T(("2`[`@@))#L2"`D$.R(("00[,@@)!
M#M""`D<.P(("0P[,@@)!#M""`D8.S(("00[(@@)!#LR"`D@.T(("2`[`@@)'
M#L2"`D4.R(("10[,@@).#M""`D@.P(("6`[$@@)!#LB"`D$.S(("1P[0@@)!
M#M2"`DH.V(("00[<@@)$#N""`D@.P(("8@[$@@)!#LB"`D<.S(("00[0@@)*
M#M2"`D0.V(("00[<@@)$#N""`D@.P(("00[$@@)!#LB"`D4.S(("1`[0@@)(
M#L""`E0.Q(("00[(@@)!#LR"`D$.T(("1`[4@@)$#MB"`D$.W(("1`[@@@)(
M#L""`D4.S(("1`[0@@)5#LR"`D0.T(("2`[`@@)>#A1!PPX00<8.#$''#@A!
MQ0X$`(`!``!X"0``F:#___P"````00X(A0)!#@R'`T$.$(8$00X4@P5.#CQ(
M#D!&#CQ"#D!;#C!7#CQ"#D!-#D1"#DA!#DQ!#E!(#C!'#CQ"#D!-#D1"#DA!
M#DQ!#E!(#C!N#CQ!#D!'#D1$#DA!#DQ!#E!(#C!U#CQ"#D!'#D1"#DA%#DQ!
M#E!(#C!!#C1!#CA!#CQ)#D!(#C!;#CQ"#D!&#CQ!#CA!#CQ!#D!(#C!(#CQ$
M#D!(#C1'#CA!#CQ!#D!+#C!+#CQ"#D!&#CQ!#CA!#CQ!#D!(#C!##CQ"#D!-
M#D1"#DA!#DQ!#E!(#C!M"@X\1`Y`2`XT00XX00X\00Y`3PM-#CQ"#D!(#C1!
M#CA!#CQ!#D!(#C!#"@X\0@Y`2`XT2`XX00X\00Y`1@X\0@Y`2@XT1PXX00X\
M00Y`1@X\0@Y`5PXP30X\1@Y`2`XP30X\2`M!#C1!#CA%#CQ&#D!(#C!.#C1,
M#CA"#CQ'#D!%#C!##A1!PPX00<8.#$''#@A!Q0X$``!0````_`H``!&B__]>
M`````$$."(<"00X,A@-!#A"#!%(.'$$.(%`.$%4.%$$.&$<.'$$.($@.$$4*
MPPX,0\8."$''#@1%"T'##@Q!Q@X(0<<.!`!$````4`L``%B*___+`0```$0,
M`0!*$`4"=0!$$`<"=7P0!@)U>$,0`P)U=$P/`W5P!@.B`<$,`0!!PT'&0<=!
MQ4,,!`0````\````F`L``-.A___<"P```$$."(4"0PX,AP-!#A"&!$$.%(,%
M1@Z0`P/+"PX40<,.$$'&#@Q!QPX(0<4.!```(````-@+``!OK?__4@````!!
M#@B#`DX.'$(.('\."$'##@0`.````/P+``"=K?__^P````!!#@B%`D$.#(<#
M00X0A@1!#A2#!4,.,`+O#A1!PPX00<8.#$''#@A!Q0X$0````#@,``!<KO__
M)P$```!+#@B%`D$.#(<#00X0A@1!#A2#!4,.,`*%#CP"@`Y`3`X40<,.$$'&
M#@Q!QPX(0<4.!``0````?`P``#^O__\$`````````!P```"0#```+Z___QD`
M````00X(@P).#A!(#@A!PPX$````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````_____P````#_____``````$```!"`P``
M`0```$T#```/````=00```P`````$```#0```&$Z``#U_O]OC`$```4```"4
M"```!@```&0"```*````DP0```L````0````%0`````````#````T)X```(`
M``#0`0``%````!$````7````V`T``!$````H#0``$@```+`````3````"```
M`!@`````````^___;P$```CZ__]O"@``````````````````````````````
M````````````````````````````G@`````````````V$```1A```%80``!F
M$```=A```(80``"6$```IA```+80``#&$```UA```.80``#V$```!A$``!81
M```F$0``-A$``$81``!6$0``9A$``'81``"&$0``EA$``*81``"V$0``QA$`
M`-81``#F$0``]A$```82```6$@``)A(``#82``!&$@``5A(``&82``!V$@``
MAA(``)82``"F$@``MA(``,82``#6$@``YA(``/82```&$P``%A,``"83```V
M$P``1A,``%83``!F$P``=A,``(83``"6$P``IA,``+83``#&$P``\!,`````
M````````83H`````````$```````````````````````````````````````
M`````````````*````5````%00``$$```!=!```80````````/____^Y0@``
M1T-#.B`H06QP:6YE(#$P+C(N,"D@,3`N,BXP```N<VAS=')T86(`+FEN=&5R
M<``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT
M`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N9'EN86UI8P`N9&%T80`N
M8G-S`"YC;VUM96YT````````````````````````````````````````````
M```````````````+`````0````(```!T`0``=`$``!<```````````````$`
M````````$P```/;__V\"````C`$``(P!``#8`````P`````````$````!```
M`!T````+`````@```&0"``!D`@``,`8```0````!````!````!`````E````
M`P````(```"4"```E`@``),$``````````````$`````````+0````D````"
M````*`T``"@-``"P`````P`````````$````"````#8````)````0@```-@-
M``#8#0``T`$```,````2````!`````@````_`````0````8`````$````!``
M`!$```````````````$`````````.@````$````&````(!```"`0``"P`P``
M```````````0````!````$4````!````!@```-`3``#0$P``&```````````
M````"`````@```!.`````0````8```#P$P``\!,``'$F`````````````!``
M````````5`````$````&````83H``&$Z```,```````````````!````````
M`%H````!`````@````!`````0```3CT`````````````!`````````!B````
M`0````(```!0?0``4'T``/0```````````````0`````````<`````$````"
M````1'X``$1^``"P#``````````````$`````````'H````!`````P```/"=
M``#PC0``"```````````````!`````````"!`````0````,```#XG0``^(T`
M``@```````````````0`````````B`````8````#`````)X```".``#0````
M!``````````$````"````$D````!`````P```-">``#0C@``,`$`````````
M````!`````0```"1`````0````,`````H````)```"0```````````````0`
M````````EP````@````#````0*```"20```T$``````````````@````````
M`)P````!````,``````````DD```'````````````````0````$````!````
D`P``````````````0)```*4```````````````$`````````
